/*
 * Copyright 2000-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.container;

import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletResponseWrapper;
import javax.portlet.RenderResponse;
import javax.portlet.ActionResponse;

import org.apache.pluto.om.portlet.PortletDefinition;

/**
 * The container response wrappers the servlet response and is used 
 * within the container to communicate to the invoked servlet.
 *
 * @author <a href="mailto:taylor@apache.org">David Sean Taylor</a>
 * @version $Id: ContainerResponse.java,v 1.2 2004/03/08 00:41:26 jford Exp $
 */
public class ContainerResponse extends HttpServletResponseWrapper
{
    RenderResponse renderResponse;
    ActionResponse actionResponse;
    PortletDefinition portletDef;

    public ContainerResponse(HttpServletResponse response,
                             PortletDefinition portletDef)
    {
        super(response);
        this.portletDef = portletDef;
    }

    public PortletDefinition getPortletDefinition()
    {
        return this.portletDef;
    }

    public RenderResponse getRenderResponse()
    {
        return renderResponse;
    }

    public void setRenderResponse(RenderResponse renderResponse)
    {
        this.renderResponse = renderResponse;
    }

    public ActionResponse getActionResponse()
    {
        return actionResponse;
    }

    public void setActionResponse(ActionResponse actionResponse)
    {
        this.actionResponse = actionResponse;
    }

}
