/*
 * Copyright 2000-2001,2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;


/**
 * implements common directory and jar operations
 *
 * @author <a href="mailto:taylor@apache.org">David Sean Taylor </a>
 * @version $Id: AbstractFileSystemHelper.java,v 1.2 2004/08/05 18:26:19 taylor Exp $
 */
public abstract class AbstractFileSystemHelper
{
    public abstract File getRootDirectory();
    
    public long getChecksum(String path)
    {
        File child = new File(getRootDirectory(), path);
        if (child == null || !child.exists())
        {
            return 0;
        }
                
        long checksum = 0;
        InputStream is = null;
        try
        {
            is = new FileInputStream(child);
            checksum = ChecksumHelper.getChecksum(is);
        }
        catch (FileNotFoundException e)
        {
        }
        finally 
        {
             if (is != null)
             {
                 try
                 {
                     is.close();
                 }
                 catch (IOException io)
                 {}
             }
        }
        return checksum;
    }

}
